@@ -21,8 +21,6 @@
 
 #include <kpanelapplet.h>
 
-#include <X11/Xlib.h>
-
 class EyesApplet : public KPanelApplet
 {
     Q_OBJECT
@@ -43,9 +41,6 @@ private:
     void drawPupils(QPainter* p);
 
     QPoint oldleft, oldright;
-    Display *display;
-    Window root, RootIDRet, ChildIDRet;
-    unsigned int StateMask;
 };
 
 #endif // __eyes_h__
