@@ -18,8 +18,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -96,7 +96,7 @@ double coordinate(QString c)
 }
 
 
-void CityList::readCityList(QString fname)
+void CityList::readCityList(const QString &fname)
 {
   QFile f(fname);
 
